@@ -34,6 +34,7 @@
 #include <gconf/gconf-client.h>
 
 #include "nautilus-burn-drive.h"
+#include "nautilus-burn-drive-monitor.h"
 #include "make-iso.h"
 
 #include "ncb-selection.h"
@@ -309,7 +310,7 @@ ncb_hig_dialog (GtkMessageType type,
 					type,
 					GTK_BUTTONS_NONE,
 					title);
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (error_dialog), reason);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (error_dialog), "%s", reason);
 	gtk_window_set_title (GTK_WINDOW (error_dialog), "");
 	gtk_window_set_icon_name (GTK_WINDOW (error_dialog), "gnome-dev-cdrom");
 
@@ -432,7 +433,6 @@ verify_source_location_contents (const char *text_uri,
 		g_list_free (unreadable_paths);
 	}
 
-
 	if (size <= 0) {
 		g_set_error (error,
 			     NCB_SELECTION_ERROR,
@@ -537,7 +537,8 @@ verify_device (NcbSelection *selection,
                 *name = NULL;
         }
 
-        drive = nautilus_burn_drive_new_from_path (selection->priv->source_name);
+	drive = nautilus_burn_drive_monitor_get_drive_for_device (nautilus_burn_get_drive_monitor (),
+								  selection->priv->source_name);
 
         if (! drive) {
                 char *msg;
@@ -562,13 +563,20 @@ verify_device (NcbSelection *selection,
                 *size = nautilus_burn_drive_get_media_size (drive);
         }
 
-        if (*size <= 0) {
+        if ((gint64) *size < 0) {
 		g_set_error (error,
 			     NCB_SELECTION_ERROR,
 			     NCB_SELECTION_ERROR_GENERAL,
 			     _("There doesn't seem to be any media in the selected drive."));
                 return FALSE;
-        }
+
+	} else if (*size == 0) {
+		g_set_error (error,
+			     NCB_SELECTION_ERROR,
+			     NCB_SELECTION_ERROR_GENERAL,
+			     _("The media is blank."));
+                return FALSE;
+	}
 
         return TRUE;
 }
